@@ -12,20 +12,10 @@ extern crate proc_macro_test;
 /// `maybe_async::maybe_async` automatically removes `async`-related keywords
 /// if feature "async_tokio" is not enabled.
 pub extern crate maybe_async;
+/// `maybe_async_attr` automatically removes `async`-related keywords
+/// if feature "async_tokio" is not enabled.
+pub use maybe_async::maybe_async as maybe_async_attr;
 
-/// Automatically start async runtime or call `loom::model` if required:
-///
-/// ```no_run
-/// #[concurrency_toolkit::test]
-/// fn test() {
-///     // ...
-/// }
-/// ```
-///
-/// However, unlike `maybe_async::maybe_async`, this proc macro requires the function
-/// to not be declared as `async` due to implementation detail
-/// (`syn` doesn't provides an easy way to parse `async function), but it still can
-/// remove `async`-related keywords just like `maybe_async::maybe_async`.
 pub use proc_macro_test::test;
 
 #[cfg(feature = "async_tokio")]
